@@ -80,7 +80,8 @@ def _dotfile_update(o, path, key=False):
     updater = Updater(o.dotpath, o.variables, o.conf,
                       dry=o.dry, safe=o.safe, debug=o.debug,
                       ignore=o.update_ignore,
-                      showpatch=o.update_showpatch)
+                      showpatch=o.update_showpatch,
+                      ignore_missing_in_dotdrop=o.ignore_missing_in_dotdrop)
     if key:
         return updater.update_key(path)
     return updater.update_path(path)
@@ -92,12 +93,15 @@ def _dotfile_compare(o, dotfile, tmp):
     returns True if same
     """
     t = _get_templater(o)
+    ignore_missing_in_dotdrop = o.ignore_missing_in_dotdrop or \
+        dotfile.ignore_missing_in_dotdrop
     inst = Installer(create=o.create, backup=o.backup,
                      dry=o.dry, base=o.dotpath,
                      workdir=o.workdir, debug=o.debug,
                      backup_suffix=o.install_backup_suffix,
                      diff_cmd=o.diff_command)
-    comp = Comparator(diff_cmd=o.diff_command, debug=o.debug)
+    comp = Comparator(diff_cmd=o.diff_command, debug=o.debug,
+                      ignore_missing_in_dotdrop=ignore_missing_in_dotdrop)
 
     # add dotfile variables
     newvars = dotfile.get_dotfile_variables()
@@ -134,8 +138,11 @@ def _dotfile_compare(o, dotfile, tmp):
             LOG.dbg('points to itself')
         return True
 
+    ignores = list(set(o.compare_ignore + dotfile.cmpignore))
+    ignores = patch_ignores(ignores, dotfile.dst, debug=o.debug)
+
     insttmp = None
-    if dotfile.template and Templategen.is_template(src):
+    if dotfile.template and Templategen.is_template(src, ignore=ignores):
         # install dotfile to temporary dir for compare
         ret, err, insttmp = inst.install_to_temp(t, tmp, src, dotfile.dst,
                                                  is_template=True,
@@ -149,8 +156,6 @@ def _dotfile_compare(o, dotfile, tmp):
         src = insttmp
 
     # compare
-    ignores = list(set(o.compare_ignore + dotfile.cmpignore))
-    ignores = patch_ignores(ignores, dotfile.dst, debug=o.debug)
     diff = comp.compare(src, dotfile.dst, ignore=ignores)
 
     # clean tmp transformed dotfile if any
@@ -207,13 +212,20 @@ def _dotfile_install(o, dotfile, tmpdir=None):
         LOG.dbg('installing dotfile: \"{}\"'.format(dotfile.key))
         LOG.dbg(dotfile.prt())
 
-    is_template = dotfile.template and Templategen.is_template(dotfile.src)
+    ignores = list(set(o.install_ignore + dotfile.instignore))
+    ignores = patch_ignores(ignores, dotfile.dst, debug=o.debug)
+
+    is_template = dotfile.template and Templategen.is_template(
+        dotfile.src,
+        ignore=ignores,
+    )
     if hasattr(dotfile, 'link') and dotfile.link == LinkTypes.LINK:
         # link
         r, err = inst.install(t, dotfile.src, dotfile.dst,
                               dotfile.link,
                               actionexec=pre_actions_exec,
                               is_template=is_template,
+                              ignore=ignores,
                               chmod=dotfile.chmod)
     elif hasattr(dotfile, 'link') and \
             dotfile.link == LinkTypes.LINK_CHILDREN:
@@ -222,7 +234,8 @@ def _dotfile_install(o, dotfile, tmpdir=None):
                               dotfile.link,
                               actionexec=pre_actions_exec,
                               is_template=is_template,
-                              chmod=dotfile.chmod)
+                              chmod=dotfile.chmod,
+                              ignore=ignores)
     else:
         # nolink
         src = dotfile.src
@@ -232,8 +245,6 @@ def _dotfile_install(o, dotfile, tmpdir=None):
             if not tmp:
                 return False, dotfile.key, None
             src = tmp
-        ignores = list(set(o.install_ignore + dotfile.instignore))
-        ignores = patch_ignores(ignores, dotfile.dst, debug=o.debug)
         r, err = inst.install(t, src, dotfile.dst,
                               LinkTypes.NOLINK,
                               actionexec=pre_actions_exec,
@@ -412,6 +423,10 @@ def cmd_update(o):
     paths = o.update_path
     iskey = o.update_iskey
 
+    if o.profile not in [p.key for p in o.profiles]:
+        LOG.err('no such profile \"{}\"'.format(o.profile))
+        return False
+
     adapt_workers(o, LOG)
 
     if not paths:
@@ -467,7 +482,7 @@ def cmd_importer(o):
     paths = o.import_path
     importer = Importer(o.profile, o.conf, o.dotpath, o.diff_command,
                         dry=o.dry, safe=o.safe, debug=o.debug,
-                        keepdot=o.keepdot)
+                        keepdot=o.keepdot, ignore=o.import_ignore)
 
     for path in paths:
         r = importer.import_path(path, import_as=o.import_as,
